@@ -11,10 +11,10 @@ describe('StreamTest', () => {
     });
   });
 
-  StreamTest.versions.forEach(version => {
+  StreamTest.versions.forEach((version) => {
     describe('for ' + version + ' streams', () => {
-      it('should work with buffers', done => {
-        const expectedBuffers = [new Buffer('test'), new Buffer('test2')];
+      it('should work with buffers', (done) => {
+        const expectedBuffers = [Buffer.from('test'), Buffer.from('test2')];
         const inputStream = StreamTest[version].fromChunks(expectedBuffers);
         const outputStream = StreamTest[version].toChunks((err, buffers) => {
           if (err) {
@@ -28,8 +28,8 @@ describe('StreamTest', () => {
         inputStream.pipe(outputStream);
       });
 
-      it('should report errors with buffers', done => {
-        const expectedBuffers = [new Buffer('test'), new Buffer('test2')];
+      it('should report errors with buffers', (done) => {
+        const expectedBuffers = [Buffer.from('test'), Buffer.from('test2')];
         const inputStream = StreamTest[version].fromErroredChunks(
           new Error('Ooops'),
           expectedBuffers
@@ -40,13 +40,13 @@ describe('StreamTest', () => {
           done();
         });
 
-        inputStream.on('error', err => {
+        inputStream.on('error', (err) => {
           outputStream.emit('error', err);
         });
         inputStream.pipe(outputStream);
       });
 
-      it('should work when wanting whole text', done => {
+      it('should work when wanting whole text', (done) => {
         const expectedBuffers = ['test', 'test2'];
         const inputStream = StreamTest[version].fromObjects(expectedBuffers);
         const outputStream = StreamTest[version].toText((err, buffers) => {
@@ -61,8 +61,8 @@ describe('StreamTest', () => {
         inputStream.pipe(outputStream);
       });
 
-      it('should report errors when wanting whole text', done => {
-        const expectedBuffers = [new Buffer('test'), new Buffer('test2')];
+      it('should report errors when wanting whole text', (done) => {
+        const expectedBuffers = [Buffer.from('test'), Buffer.from('test2')];
         const inputStream = StreamTest[version].fromErroredChunks(
           new Error('Ooops'),
           expectedBuffers
@@ -73,14 +73,14 @@ describe('StreamTest', () => {
           done();
         });
 
-        inputStream.on('error', err => {
+        inputStream.on('error', (err) => {
           outputStream.emit('error', err);
         });
 
         inputStream.pipe(outputStream);
       });
 
-      it('should work with objects', done => {
+      it('should work with objects', (done) => {
         const expectedObjs = [
           {
             test: 'test',
@@ -102,7 +102,7 @@ describe('StreamTest', () => {
         inputStream.pipe(outputStream);
       });
 
-      it('should report errors with objects', done => {
+      it('should report errors with objects', (done) => {
         const expectedObjs = [
           {
             test: 'test',
@@ -121,7 +121,7 @@ describe('StreamTest', () => {
           done();
         });
 
-        inputStream.on('error', err => {
+        inputStream.on('error', (err) => {
           outputStream.emit('error', err);
         });
 
